==> 0.0.56.tar.gz: lib/widget/dialog/custom_dialog_success.dart <==

import '../../common/values/sizes.dart';
import '../../common/values/styles.dart';
import '../custom/custom_icon.dart';
import '../custom/spaces.dart';
import '../text/custom_text_header_medium_field.dart';
import '../text/custom_text_medium_field.dart';
import 'package:flutter/material.dart';

class CustomDialogSuccess extends StatelessWidget {
  final String? title, content;
  final String positiveBtnText;
  final GestureTapCallback positiveBtnPressed;

  CustomDialogSuccess(
      {required this.title,
      required this.positiveBtnText,
      required this.positiveBtnPressed,
      this.content});

  @override
  Widget build(BuildContext context) {
    return Dialog(
      elevation: 0,
      backgroundColor: Colors.transparent,
      child: _buildDialogContent(context),
    );
  }

  Widget _buildDialogContent(BuildContext context) {
    return WillPopScope(
      onWillPop: () async => false,
      child: Stack(
        alignment: Alignment.topCenter,
        children: <Widget>[
          Container(
            margin: EdgeInsets.only(
                top: 40), // to push the box half way below circle
            decoration: BoxDecoration(
                color: Colors.white, borderRadius: BorderRadius.circular(10)),
            child: Column(
              mainAxisSize: MainAxisSize.min,
              children: <Widget>[
                Container(
                  width: Sizes.width(context),
                  height: Sizes.HEIGHT_52,
                  decoration: BoxDecoration(
                    color: Colors.green,
                    borderRadius: BorderRadius.only(
                        topLeft: Radius.circular(10),
                        topRight: Radius.circular(10)),
                  ),
                  child: Row(
                    mainAxisAlignment: MainAxisAlignment.center,
                    crossAxisAlignment: CrossAxisAlignment.center,
                    children: [
                      CustomTextHeaderMediumField(
                        label: title,
                        align: TextAlign.center,
                        color: Colors.white,
                      ),
                      SpaceW8(),
                      CustomIcon(
                        icon: Icons.check,
                        color: Colors.white,
                        size: 24,
                      )
                    ],
                  ),
                ),
                SpaceH10(),
                content != null
                    ? Padding(
                        padding: const EdgeInsets.symmetric(horizontal: 8),
                        child: CustomTextMediumField(
                          label: content,
                          align: TextAlign.center,
                          maxLine: 4,
                        ),
                      )
                    : Container(),
                SpaceH10(),
                Row(
                  mainAxisSize: MainAxisSize.max,
                  mainAxisAlignment: MainAxisAlignment.spaceEvenly,
                  children: <Widget>[
                    Expanded(
                      flex: 1,
                      child: TextButton(
                        child: Text(
                          positiveBtnText,
                          style: Styles.customTextMediumStyle(
                              color: Theme.of(context).colorScheme.secondary),
                        ),
                        onPressed: positiveBtnPressed,
                      ),
                    )
                  ],
                ),
              ],
            ),
          ),
        ],
      ),
    );
  }
}

==> 0.0.64.tar.gz: lib/widget/dialog/custom_dialog_success.dart <==

import '../../common/values/sizes.dart';
import '../../common/values/styles.dart';
import '../custom/custom_icon.dart';
import '../custom/spaces.dart';
import '../text/custom_text_header_medium_field.dart';
import '../text/custom_text_medium_field.dart';
import 'package:flutter/material.dart';

class CustomDialogSuccess extends StatelessWidget {
  final String? title, content;
  final String positiveBtnText;
  final GestureTapCallback positiveBtnPressed;

  CustomDialogSuccess(
      {required this.title,
      required this.positiveBtnText,
      required this.positiveBtnPressed,
      this.content});

  @override
  Widget build(BuildContext context) {
    return Dialog(
      elevation: 0,
      backgroundColor: Colors.transparent,
      child: _buildDialogContent(context),
    );
  }

  Widget _buildDialogContent(BuildContext context) {
    return WillPopScope(
      onWillPop: () async => false,
      child: Stack(
        alignment: Alignment.topCenter,
        children: <Widget>[
          Container(
            margin: EdgeInsets.only(
                top: Sizes.PADDING_40), // to push the box half way below circle
            decoration: BoxDecoration(
                color: Colors.white, borderRadius: BorderRadius.circular(10)),
            child: Column(
              mainAxisSize: MainAxisSize.min,
              children: <Widget>[
                Container(
                  width: Sizes.width(context),
                  height: Sizes.HEIGHT_52,
                  decoration: BoxDecoration(
                    color: Colors.green,
                    borderRadius: BorderRadius.only(
                        topLeft: Radius.circular(10),
                        topRight: Radius.circular(10)),
                  ),
                  child: Row(
                    mainAxisAlignment: MainAxisAlignment.center,
                    crossAxisAlignment: CrossAxisAlignment.center,
                    children: [
                      CustomTextHeaderMediumField(
                        label: title,
                        align: TextAlign.center,
                        color: Colors.white,
                      ),
                      SpaceW8(),
                      CustomIcon(
                        icon: Icons.check,
                        color: Colors.white,
                        size: Sizes.ICON_SIZE_24,
                      )
                    ],
                  ),
                ),
                SpaceH10(),
                content != null
                    ? Padding(
                        padding: EdgeInsets.symmetric(horizontal: Sizes.PADDING_8),
                        child: CustomTextMediumField(
                          label: content,
                          align: TextAlign.center,
                          maxLine: 4,
                        ),
                      )
                    : Container(),
                SpaceH10(),
                Row(
                  mainAxisSize: MainAxisSize.max,
                  mainAxisAlignment: MainAxisAlignment.spaceEvenly,
                  children: <Widget>[
                    Expanded(
                      flex: 1,
                      child: TextButton(
                        child: Text(
                          positiveBtnText,
                          style: Styles.customTextMediumStyle(
                              color: Theme.of(context).colorScheme.secondary),
                        ),
                        onPressed: positiveBtnPressed,
                      ),
                    )
                  ],
                ),
              ],
            ),
          ),
        ],
      ),
    );
  }
}
